import 'package:flutter/material.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:mockito/mockito.dart';
import 'package:vudu_mojo_app/transitions/fadeRoute.dart';

class MockBuildContext extends Mock implements BuildContext {}

void main() {
  testWidgets('FadeRoute navigation should work correctly',
      (WidgetTester tester) async {
    //Arrange
    Widget testableWidget = MaterialApp(
      home: Scaffold(
        body: Column(
          children: <Widget>[
            Builder(builder: (context) {
              return ElevatedButton(
                child: Text('Go to second page'),
                onPressed: () {
                  Navigator.of(context).pushNamed('/second');
                },
              );
            }),
          ],
        ),
      ),
      onGenerateRoute: (settings) {
        if (settings.name == '/second') {
          return FadeRoute(page: Scaffold(body: Text('Second')));
        }
        return null;
      },
    );

    await tester.pumpWidget(testableWidget);

    //Act
    await tester.tap(find.text('Go to second page'));
    await tester.pumpAndSettle();

    //Assert
    expect(find.text('Second'), findsOneWidget);
  });
}
